function [error] = readBucketData( hTsgGUI, filename)
% Function to read Bucket data in ASCII format. 
%
% Input
% -----
% hTsgGUI ............ Handel to the main user interface
% filename ........... Data filename
%
% Output
% ------
% error .............. 1: OK - -1 : an error occured
%
% @The data are store using setappdata - Variable name : 'bucketASCII'
%
% Caution : replace the fill-value with NaN
% $Id$

% Open the file
% -------------
fid = fopen( filename, 'r' );

error = -1;
if fid ~= -1

    % Get the tsg structure from application GUI
    % ------------------------------------------
    tsg = getappdata( hTsgGUI, 'tsg_data');
    
    % Read the file - skip 2 lines
    % ----------------------------
    fgetl( fid );
    fgetl( fid );    % Bottle type: OSI - tsg.PSAL_WS_BOTTLE   =  ;
    
    % Read date of analysis. Convert to NetCdf format
    % ------------------------------------------------
%     tab = fscanf(fid,'Date of water sample analysis: %d/%d/%d\n');
%     psal_ws_analdayd = datenum(tab(3), tab(2), tab(1), 0, 0, 0);
%     tsg.PSAL_WS_ANALDATE = datestr(  psal_ws_analdayd, 'yyyymmddHHMMSS' );
    a = fscanf(fid,'%SSPS_WS_ANALDATE %s\n');
    
    fgetl( fid );
    
    % Read the data - prefer to read string with textscan because if some
    % integer are replace with NaN fscanf read the NaN as 0
    % -------------------------------------------------------------------
    C = textscan(fid,'%s %s %s %s %s %s %s %s %s', [9 Inf])';
    yy(:,1)    = str2num( char( C{1} ) );
    mm(:,1)    = str2num( char( C{2} ) );
    dd(:,1)    = str2num( char( C{3} ) );
    hh(:,1)    = str2num( char( C{4} ) );
    min(:,1)   = str2num( char( C{5} ) );
    lat(:,1)   = str2num( char( C{6} ) );
    lon(:,1)   = str2num( char( C{7} ) );
    sss(:,1)   = str2num( char( C{8} ) );
    code(:,1)  = str2num( char( C{9} ) );

    %bucketData = fscanf(fid,'%d %d %d %d %d %f %f %f %d', [9 Inf])';
    
    % Eliminate records with no date
    % ------------------------------
    dayd = datenum(yy, mm, dd, hh, min, 0);
    ind = find( isnan(dayd) == 1 );
    yy(ind) = [];   mm(ind) = [];  dd(ind) = [];  hh(ind) = [];  min(ind)  = [];
    lat(ind) = [];  lon(ind) = []; sss(ind) = []; code(ind) = [];

    % Convert to numeric Matlab date
    % ------------------------------
    tsg.DAYD_WS   = datenum(yy, mm, dd, hh, min, 0);
                           
    % save original date  
    % ------------------
    tsg.DATE_WS    = deblank( datestr(  tsg.DAYD_WS, 'yyyymmddHHMMSS' ));                     
   
    tsg.LATX_WS    = lat;
    tsg.LONX_WS    = lon;
    tsg.SSPS_WS    = sss;
    
    % QC codes are of type BYTE - conversion
    % --------------------------------------
    tsg.SSPS_WS_QC = int8(code);
    
    % Sort the struct tsg - increasing time.
    % -----------------------------------------
    if ~isempty(tsg.DAYD_WS)
      [tsg.DAYD_WS, iOrder] = sort(tsg.DAYD_WS);
      tsg.DATE_WS           = tsg.DATE_WS(iOrder,:);
      tsg.LATX_WS           = tsg.LATX_WS(iOrder);
      tsg.LONX_WS           = tsg.LONX_WS(iOrder);
      tsg.SSPS_WS           = tsg.SSPS_WS(iOrder);
      tsg.SSPS_WS_QC        = tsg.SSPS_WS_QC(iOrder);
    end

    % Keep the name of the file for the log file
    % ------------------------------------------
    tsg.report.wsfile   = filename;
    
    % Save the data in the application GUI
    % ------------------------------------
    setappdata( hTsgGUI, 'tsg_data', tsg );
    
    % Clear the Workspace
    % -------------------
    clear bucketData
    
    % Close the file
    % --------------
    fclose( fid );
    
    % Everything OK
    % -------------
    error = 1;
end
